
# This file was generated by 'versioneer.py' (0.21) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-02-08T23:10:27+0100",
 "dirty": false,
 "error": null,
 "full-revisionid": "877a3a46cf6a77784ded03d6edf36ddc0cdc9573",
 "version": "0.7.6"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
